Add an API around InterstitialPage that's used by chrome.

BUG=98716
Review URL: https://chromiumcodereview.appspot.com/9348064

git-svn-id: svn://svn.chromium.org/chrome/trunk/src@121059 0039d316-1c4b-4281-b951-d872f2087c98
diff --git a/content/browser/tab_contents/tab_contents.h b/content/browser/tab_contents/tab_contents.h
index aef97ef..baeb781 100644
--- a/content/browser/tab_contents/tab_contents.h
+++ b/content/browser/tab_contents/tab_contents.h
@@ -30,6 +30,7 @@
 #include "base/win/scoped_handle.h"
 #endif
 
+class InterstitialPageImpl;
 class LoadNotificationDetails;
 class RenderViewHost;
 class SavePackage;
@@ -99,7 +100,7 @@
   // |interstitial_page| should be non NULL (use the remove_interstitial_page
   // method to unset the interstitial) and no interstitial page should be set
   // when there is already a non NULL interstitial page set.
-  void set_interstitial_page(InterstitialPage* interstitial_page) {
+  void set_interstitial_page(InterstitialPageImpl* interstitial_page) {
     render_manager_.set_interstitial_page(interstitial_page);
   }
 
@@ -181,7 +182,7 @@
   virtual void Focus() OVERRIDE;
   virtual void FocusThroughTabTraversal(bool reverse) OVERRIDE;
   virtual bool ShowingInterstitialPage() const OVERRIDE;
-  virtual InterstitialPage* GetInterstitialPage() const OVERRIDE;
+  virtual content::InterstitialPage* GetInterstitialPage() const OVERRIDE;
   virtual bool IsSavable() OVERRIDE;
   virtual void OnSavePage() OVERRIDE;
   virtual bool SavePage(const FilePath& main_file,
@@ -367,8 +368,8 @@
   friend class TabContentsViewGtk;
 #endif
 
-  // So InterstitialPage can access SetIsLoading.
-  friend class InterstitialPage;
+  // So InterstitialPageImpl can access SetIsLoading.
+  friend class InterstitialPageImpl;
 
   // TODO(brettw) TestTabContents shouldn't exist!
   friend class TestTabContents;